@@ -4,36 +4,37 @@ and ensures we can use the tracking API to communicate with it.
 """
 import json
 import os
-import sys
 import posixpath
-import pytest
 import shutil
-import time
+import sys
 import tempfile
-from unittest import mock
+import time
 import urllib.parse
+from unittest import mock
+
+import pytest
 
 import mlflow.experiments
-from mlflow.exceptions import MlflowException
-from mlflow.entities import Metric, Param, RunTag, ViewType
-from mlflow.models import Model
-
 import mlflow.pyfunc
+from mlflow.entities import Metric, Param, RunTag, ViewType
+from mlflow.exceptions import MlflowException
+from mlflow.models import Model
 from mlflow.tracking import MlflowClient
-from mlflow.utils.file_utils import TempDir
+from mlflow.utils.file_utils import TempDir, path_to_local_file_uri
 from mlflow.utils.mlflow_tags import (
-    MLFLOW_USER,
-    MLFLOW_RUN_NAME,
-    MLFLOW_PARENT_RUN_ID,
-    MLFLOW_SOURCE_TYPE,
-    MLFLOW_SOURCE_NAME,
-    MLFLOW_PROJECT_ENTRY_POINT,
     MLFLOW_GIT_COMMIT,
+    MLFLOW_PARENT_RUN_ID,
+    MLFLOW_PROJECT_ENTRY_POINT,
+    MLFLOW_RUN_NAME,
+    MLFLOW_SOURCE_NAME,
+    MLFLOW_SOURCE_TYPE,
+    MLFLOW_USER,
 )
-from mlflow.utils.file_utils import path_to_local_file_uri
-
 from tests.integration.utils import invoke_cli_runner
-from tests.tracking.integration_test_utils import _await_server_down_or_die, _init_server
+from tests.tracking.integration_test_utils import (
+    _await_server_down_or_die,
+    _init_server,
+)
 
 # pylint: disable=unused-argument
 
@@ -118,7 +119,7 @@ def cli_env(tracking_server_uri):
 
 def test_create_get_list_experiment(mlflow_client):
     experiment_id = mlflow_client.create_experiment(
-        "My Experiment", artifact_location="my_location", tags={"key1": "val1", "key2": "val2"}
+        "My Experiment", storage_root="my_location", tags={"key1": "val1", "key2": "val2"}
     )
     exp = mlflow_client.get_experiment(experiment_id)
     assert exp.name == "My Experiment"
