@@ -407,9 +407,11 @@ def server(
     if not backend_store_uri:
         backend_store_uri = DEFAULT_LOCAL_FILE_AND_ARTIFACT_PATH
 
-    default_artifact_root = resolve_default_artifact_root(
-        serve_artifacts, default_artifact_root, backend_store_uri
-    )
+    # No need of default artifact root env var going forward
+    default_artifact_root = None
+    # default_artifact_root = resolve_default_artifact_root(
+    #     serve_artifacts, default_artifact_root, backend_store_uri
+    # )
 
     try:
         initialize_backend_stores(backend_store_uri, default_artifact_root)
