@@ -2,9 +2,13 @@
 The ``mlflow.entities`` module defines entities returned by the MLflow
 `REST API <../rest-api.html>`_.
 """
-from mlflow.entities.auth_enums import EntityType, PrivacyType, Role, SubjectType
+from mlflow.entities.auth_enums import (
+    EntityType,
+    ExperimentAction,
+    PrivacyType,
+    SubjectType,
+)
 from mlflow.entities.columns import Columns
-from mlflow.entities.entity_subject_role import EntitySubjectRole
 from mlflow.entities.experiment import Experiment
 from mlflow.entities.experiment_tag import ExperimentTag
 from mlflow.entities.file_info import FileInfo
@@ -15,6 +19,7 @@ from mlflow.entities.mlfoundry_artifacts.artifact_version_in_transit import (
     ArtifactVersionInTransit,
 )
 from mlflow.entities.mlfoundry_artifacts.custom_metric import CustomMetric
+from mlflow.entities.mlfoundry_artifacts.datasets.dataset import Dataset
 from mlflow.entities.mlfoundry_artifacts.enums import (
     ArtifactType,
     ArtifactVersionStatus,
@@ -59,8 +64,6 @@ __all__ = [
     "LifecycleStage",
     "SubjectType",
     "EntityType",
-    "Role",
-    "EntitySubjectRole",
     "Columns",
     "RunLog",
     "SENTINEL",
@@ -83,4 +86,5 @@ __all__ = [
     "CustomMetricType",
     "CustomMetricValueType",
     "SignedURL",
+    "Dataset",
 ]
