@@ -15,8 +15,8 @@ class LifecycleStage:
             stages.append(cls.ACTIVE)
         if view_type == ViewType.DELETED_ONLY or view_type == ViewType.ALL:
             stages.append(cls.DELETED)
-        # We cant allow user to seaarch_runs that are hard deleted.
-        # So view_type HARD_DELETE_ONLY is not included here
+        if view_type == ViewType.HARD_DELETED_ONLY:
+            stages.append(cls.HARD_DELETED)
         return stages
 
     @classmethod
@@ -34,5 +34,7 @@ class LifecycleStage:
             return lifecycle_stage == LifecycleStage.ACTIVE
         elif view_type == ViewType.DELETED_ONLY:
             return lifecycle_stage == LifecycleStage.DELETED
+        elif view_type == ViewType.HARD_DELETED_ONLY:
+            return lifecycle_stage == LifecycleStage.HARD_DELETED
         else:
             raise MlflowException("Invalid view type '%s'" % str(view_type))
