@@ -74,7 +74,11 @@ class AbstractStore:
 
     @abstractmethod
     def list_experiments(
-        self, ids=None, view_type=ViewType.ACTIVE_ONLY, max_results=None, page_token=None
+        self,
+        ids=None,
+        view_type=ViewType.ACTIVE_ONLY,
+        max_results=None,
+        page_token=None,
     ):
         """
         :ids: list of experiment ids which will be fetched with the api
@@ -92,14 +96,18 @@ class AbstractStore:
         pass
 
     @abstractmethod
-    def create_experiment(self, name, artifact_location, tags, description):
+    def create_experiment(
+        self, name, tags, description, storage_integration_id=None, storage_integration_fqn=None
+    ):
         """
         Create a new experiment.
         If an experiment with the given name already exists, throws exception.
 
         :param name: Desired name for an experiment
-        :param artifact_location: Base location for artifacts in runs. May be None.
         :param tags: Experiment tags to set upon experiment creation
+        :param description: Experiment description to set upon experiment creation
+        :param storage_integration_id: Storage integration id to set upon experiment creation. can be none (default will be chosen)
+        :param storage_integration_fqn: Storage integration fqn to set upon experiment creation. can be none (default will be chosen)
 
         :return: experiment_id (string) for the newly created experiment if successful, else None.
         """
@@ -559,6 +567,7 @@ class AbstractStore:
         artifact_metadata: typing.Optional[typing.Dict[str, typing.Any]] = None,
         data_path: typing.Optional[str] = None,
         step: typing.Optional[int] = None,
+        artifact_size: typing.Optional[int] = None,
     ) -> ArtifactVersion:
         raise NotImplementedError()
 
@@ -662,6 +671,7 @@ class AbstractStore:
         description: typing.Optional[str] = SENTINEL,
         artifact_metadata: typing.Dict[str, typing.Any] = SENTINEL,
         model_schema: ModelSchema = SENTINEL,
+        model_framework: typing.Optional[str] = None,
     ) -> ModelVersion:
         raise NotImplementedError()
 
