@@ -320,7 +320,7 @@ class FileStore(AbstractStore):
                     databricks_pb2.RESOURCE_ALREADY_EXISTS,
                 )
 
-    def create_experiment(self, name, artifact_location=None, tags=None, description=None):
+    def create_experiment(self, name, storage_root=None, tags=None, description=None, storage_integration_fqn=None):
         self._check_root_dir()
         self._validate_experiment_name(name)
         # Get all existing experiments and find the one with largest numerical ID.
@@ -331,7 +331,7 @@ class FileStore(AbstractStore):
             if e.experiment_id.isdigit()
         ]
         experiment_id = max(experiments_ids) + 1 if experiments_ids else 0
-        return self._create_experiment_with_id(name, str(experiment_id), artifact_location, tags)
+        return self._create_experiment_with_id(name, str(experiment_id), storage_root, tags)
 
     def _has_experiment(self, experiment_id):
         return self._get_experiment_path(experiment_id) is not None
