@@ -433,15 +433,14 @@ class MlflowClient:
     def create_experiment(
         self,
         name: str,
-        artifact_location: Optional[str] = None,
         tags: Optional[Dict[str, Any]] = None,
         description: Optional[str] = None,
+        storage_integration_fqn: Optional[str] = None,
     ) -> str:
         """Create an experiment.
 
         :param name: The experiment name. Must be unique.
-        :param artifact_location: The location to store run artifacts.
-                                  If not provided, the server picks an appropriate default.
+        :param storage_integration_fqn: The storage integration FQN to use for the experiment for saving artifacts.
         :param tags: A dictionary of key-value pairs that are converted into
                                 :py:class:`mlflow.entities.ExperimentTag` objects, set as
                                 experiment tags upon experiment creation.
@@ -475,7 +474,10 @@ class MlflowClient:
             Lifecycle_stage: active
         """
         return self._tracking_client.create_experiment(
-            name, artifact_location, tags, description=description
+            name=name,
+            tags=tags,
+            description=description,
+            storage_integration_fqn=storage_integration_fqn,
         )
 
     def delete_experiment(self, experiment_id: str) -> None:
@@ -1789,6 +1791,7 @@ class MlflowClient:
         artifact_metadata: Optional[Dict[str, Any]] = None,
         data_path: Optional[str] = None,
         step: int = 0,
+        artifact_size: Optional[int] = None,
     ) -> ArtifactVersion:
         return self._tracking_client.finalize_artifact_version(
             version_id=version_id,
@@ -1797,6 +1800,7 @@ class MlflowClient:
             artifact_metadata=artifact_metadata,
             data_path=data_path,
             step=step,
+            artifact_size=artifact_size,
         )
 
     def get_artifact_version_by_id(self, version_id: uuid.UUID) -> ArtifactVersion:
