@@ -1,9 +1,13 @@
 import logging
 import os
+import re
+import sys
 
 import yaml
-from packaging.requirements import InvalidRequirement, Requirement
+from packaging.requirements import Requirement, InvalidRequirement
 
+from mlflow.exceptions import MlflowException
+from mlflow.protos.databricks_pb2 import INVALID_PARAMETER_VALUE
 from mlflow.utils import PYTHON_VERSION
 from mlflow.utils.requirements_utils import (
     _get_pinned_requirement,
@@ -22,16 +26,166 @@ channels:
 _CONDA_ENV_FILE_NAME = "conda.yaml"
 _REQUIREMENTS_FILE_NAME = "requirements.txt"
 _CONSTRAINTS_FILE_NAME = "constraints.txt"
+_PYTHON_ENV_FILE_NAME = "python_env.yaml"
+
+# Note this regular expression does not cover all possible patterns
+_CONDA_DEPENDENCY_REGEX = re.compile(
+    r"^(?P<package>python|pip|setuptools|wheel)"
+    r"(?P<operator><|>|<=|>=|=|==|!=)?"
+    r"(?P<version>[\d.]+)?$"
+)
 TFY_MLFLOW_CLIENT = "tfy-mlflow-client"
 MLFLOW = "mlflow"
 
 
+class _PythonEnv:
+    """
+    Represents environment information for an MLflow Model.
+    """
+
+    BUILD_PACKAGES = ("pip", "setuptools", "wheel")
+
+    def __init__(self, python=None, build_dependencies=None, dependencies=None):
+        if python is not None and not isinstance(python, str):
+            raise TypeError(f"`python` must be a string but got {type(python)}")
+        if build_dependencies is not None and not isinstance(build_dependencies, list):
+            raise TypeError(
+                f"`build_dependencies` must be a list but got {type(build_dependencies)}"
+            )
+        if dependencies is not None and not isinstance(dependencies, list):
+            raise TypeError(f"`dependencies` must be a list but got {type(dependencies)}")
+
+        self.python = python
+        self.build_dependencies = build_dependencies
+        self.dependencies = dependencies
+
+    def __str__(self):
+        return str(self.to_dict())
+
+    @classmethod
+    def current(cls):
+        return cls(
+            python=cls._get_current_python(),
+            build_dependencies=cls.get_current_build_dependencies(),
+            dependencies=[f"-r {_REQUIREMENTS_FILE_NAME}"],
+        )
+
+    @staticmethod
+    def _get_current_python():
+        return ".".join(map(str, sys.version_info[:3]))
+
+    @staticmethod
+    def _get_package_version(package_name):
+        try:
+            return __import__(package_name).__version__
+        except (ImportError, AttributeError):
+            return None
+
+    @staticmethod
+    def get_current_build_dependencies():
+        build_dependencies = []
+        for package in _PythonEnv.BUILD_PACKAGES:
+            version = _PythonEnv._get_package_version(package)
+            dep = (package + "==" + version) if version else package
+            build_dependencies.append(dep)
+        return build_dependencies
+
+    def to_dict(self):
+        return self.__dict__.copy()
+
+    @classmethod
+    def from_dict(cls, dct):
+        return cls(**dct)
+
+    def to_yaml(self, path):
+        with open(path, "w") as f:
+            # Exclude None and empty lists
+            data = {k: v for k, v in self.to_dict().items() if v}
+            yaml.safe_dump(data, f, sort_keys=False, default_flow_style=False)
+
+    @classmethod
+    def from_yaml(cls, path):
+        with open(path) as f:
+            return cls.from_dict(yaml.safe_load(f))
+
+    @staticmethod
+    def get_dependencies_from_conda_yaml(path):
+        with open(path) as f:
+            conda_env = yaml.safe_load(f)
+
+        python = None
+        build_dependencies = None
+        unmatched_dependencies = []
+        dependencies = None
+        for dep in conda_env.get("dependencies", []):
+            if isinstance(dep, str):
+                match = _CONDA_DEPENDENCY_REGEX.match(dep)
+                if not match:
+                    unmatched_dependencies.append(dep)
+                    continue
+                package = match.group("package")
+                operator = match.group("operator")
+                version = match.group("version")
+
+                # Python
+                if not python and package == "python":
+                    if operator is None:
+                        raise MlflowException(
+                            f"Invalid dependency for python: {dep}. "
+                            "It must be pinned (e.g. python=3.8.13).",
+                            error_code=INVALID_PARAMETER_VALUE
+                        )
+
+                    if operator in ("<", ">", "!="):
+                        raise MlflowException(
+                            f"Invalid version comparator for python: '{operator}'. "
+                            "Must be one of ['<=', '>=', '=', '=='].",
+                            error_code=INVALID_PARAMETER_VALUE,
+                        )
+                    python = version
+                    continue
+
+                # Build packages
+                if build_dependencies is None:
+                    build_dependencies = []
+                # "=" is an invalid operator for pip
+                operator = "==" if operator == "=" else operator
+                build_dependencies.append(package + (operator or "") + (version or ""))
+            elif _is_pip_deps(dep):
+                dependencies = dep["pip"]
+            else:
+                raise MlflowException(
+                    f"Invalid conda dependency: {dep}. Must be str or dict in the form of "
+                    '{"pip": [...]}',
+                    error_code=INVALID_PARAMETER_VALUE,
+                )
+
+        if python is None:
+            raise MlflowException(
+                f"Could not extract python version from {path}",
+                error_code=INVALID_PARAMETER_VALUE,
+            )
+
+        if unmatched_dependencies:
+            _logger.warning(
+                "The following conda dependencies will not be installed in the resulting "
+                "environment: %s",
+                unmatched_dependencies,
+            )
+
+        return dict(python=python, build_dependencies=build_dependencies, dependencies=dependencies)
+
+    @classmethod
+    def from_conda_yaml(cls, path):
+        return cls.from_dict(cls.get_dependencies_from_conda_yaml(path))
+
+
 def _mlflow_conda_env(
-    path=None,
-    additional_conda_deps=None,
-    additional_pip_deps=None,
-    additional_conda_channels=None,
-    install_mlflow=True,
+        path=None,
+        additional_conda_deps=None,
+        additional_pip_deps=None,
+        additional_conda_channels=None,
+        install_mlflow=True,
 ):
     """
     Creates a Conda environment with the specified package channels and dependencies. If there are
@@ -261,7 +415,6 @@ def _is_package_requirement(requirement_string, package: str):
 
         # TODO: Return True if `requirement_string` represents a project directory for MLflow
         # (e.g. '/path/to/mlflow') or git repository URL (e.g. 'https://github.com/mlflow/mlflow').
-        return False
 
 
 def _remove_mlflow_requirement(requirements):
@@ -277,12 +430,12 @@ def _remove_tfy_mlflow_requirement(requirements):
         requirement
         for requirement in requirements
         if not _is_package_requirement(requirement, package=TFY_MLFLOW_CLIENT)
-        and not _is_package_requirement(requirement, package=TFY_MLFLOW_CLIENT.replace("-", "_"))
+           and not _is_package_requirement(requirement, package=TFY_MLFLOW_CLIENT.replace("-", "_"))
     ]
 
 
 def _process_pip_requirements(
-    default_pip_requirements, pip_requirements=None, extra_pip_requirements=None
+        default_pip_requirements, pip_requirements=None, extra_pip_requirements=None
 ):
     """
     Processes `pip_requirements` and `extra_pip_requirements` passed to `mlflow.*.save_model` or
