@@ -10,3 +10,7 @@ def conv_longdate_to_str(longdate, local_tz=True):
         str_long_date += " " + reference.LocalTimezone().tzname(date_time)
 
     return str_long_date
+
+
+def now_utc() -> datetime.datetime:
+    return datetime.datetime.now(tz=datetime.timezone.utc)
